@@ -34,16 +34,16 @@ def register() -> None:
 
 @app.command()
 def run(
-    scene_length_min: Optional[int] = None,
-    afterglow_length_min: Optional[int] = None,
-    lights: Optional[list[str]] = None,
+    scene_length_min: Optional[int] = typer.Option(None),
+    afterglow_length_min: Optional[int] = typer.Option(None),
+    lights: list[str] = typer.Option([]),
 ) -> None:
     config = Config.from_file()
     if scene_length_min is not None:
         config.total_scene_length_min = scene_length_min
     if afterglow_length_min is not None:
         config.afterglow_length_min = afterglow_length_min
-    if lights is not None:
+    if len(lights) > 0:
         config.lights = lights
     con = Connector.from_config(config)
     try:
@@ -112,7 +112,7 @@ def set_afterglow(minutes: int) -> None:
 
 @config_app.command("reset")
 def reset_config() -> None:
-    Config.reset()
+    Config.from_file().reset()
 
 
 if __name__ == "__main__":
